# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/aws_iam_role_binding.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gateway/aws_iam_role_binding.proto',
  package='gateway',
  syntax='proto3',
  serialized_options=b'Z\n./;gateway',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"gateway/aws_iam_role_binding.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x93\x01\n\x11\x41wsIamRoleBinding\x12\x1a\n\naccount_id\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x37\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x16\n\tprincipal\x18\x03 \x01(\tB\x03\xe0\x41\x02\x12\x11\n\x04role\x18\x04 \x01(\tB\x03\xe0\x41\x02\"t\n\x1e\x43reateAwsIamRoleBindingRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12=\n\x14\x61ws_iam_role_binding\x18\x02 \x01(\x0b\x32\x1a.gateway.AwsIamRoleBindingB\x03\xe0\x41\x02\"\x91\x01\n\x1dListAwsIamRoleBindingsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"\x88\x01\n\x1eListAwsIamRoleBindingsResponse\x12\x39\n\x15\x61ws_iam_role_bindings\x18\x01 \x03(\x0b\x32\x1a.gateway.AwsIamRoleBinding\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"_\n\x1e\x44\x65leteAwsIamRoleBindingRequest\x12=\n\x14\x61ws_iam_role_binding\x18\x02 \x01(\x0b\x32\x1a.gateway.AwsIamRoleBindingB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_AWSIAMROLEBINDING = _descriptor.Descriptor(
  name='AwsIamRoleBinding',
  full_name='gateway.AwsIamRoleBinding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='gateway.AwsIamRoleBinding.account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='gateway.AwsIamRoleBinding.create_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='principal', full_name='gateway.AwsIamRoleBinding.principal', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='gateway.AwsIamRoleBinding.role', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=261,
)


_CREATEAWSIAMROLEBINDINGREQUEST = _descriptor.Descriptor(
  name='CreateAwsIamRoleBindingRequest',
  full_name='gateway.CreateAwsIamRoleBindingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.CreateAwsIamRoleBindingRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aws_iam_role_binding', full_name='gateway.CreateAwsIamRoleBindingRequest.aws_iam_role_binding', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=379,
)


_LISTAWSIAMROLEBINDINGSREQUEST = _descriptor.Descriptor(
  name='ListAwsIamRoleBindingsRequest',
  full_name='gateway.ListAwsIamRoleBindingsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.ListAwsIamRoleBindingsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='gateway.ListAwsIamRoleBindingsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='gateway.ListAwsIamRoleBindingsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='gateway.ListAwsIamRoleBindingsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='gateway.ListAwsIamRoleBindingsRequest.order_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=382,
  serialized_end=527,
)


_LISTAWSIAMROLEBINDINGSRESPONSE = _descriptor.Descriptor(
  name='ListAwsIamRoleBindingsResponse',
  full_name='gateway.ListAwsIamRoleBindingsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aws_iam_role_bindings', full_name='gateway.ListAwsIamRoleBindingsResponse.aws_iam_role_bindings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='gateway.ListAwsIamRoleBindingsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_size', full_name='gateway.ListAwsIamRoleBindingsResponse.total_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=530,
  serialized_end=666,
)


_DELETEAWSIAMROLEBINDINGREQUEST = _descriptor.Descriptor(
  name='DeleteAwsIamRoleBindingRequest',
  full_name='gateway.DeleteAwsIamRoleBindingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aws_iam_role_binding', full_name='gateway.DeleteAwsIamRoleBindingRequest.aws_iam_role_binding', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=668,
  serialized_end=763,
)

_AWSIAMROLEBINDING.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CREATEAWSIAMROLEBINDINGREQUEST.fields_by_name['aws_iam_role_binding'].message_type = _AWSIAMROLEBINDING
_LISTAWSIAMROLEBINDINGSRESPONSE.fields_by_name['aws_iam_role_bindings'].message_type = _AWSIAMROLEBINDING
_DELETEAWSIAMROLEBINDINGREQUEST.fields_by_name['aws_iam_role_binding'].message_type = _AWSIAMROLEBINDING
DESCRIPTOR.message_types_by_name['AwsIamRoleBinding'] = _AWSIAMROLEBINDING
DESCRIPTOR.message_types_by_name['CreateAwsIamRoleBindingRequest'] = _CREATEAWSIAMROLEBINDINGREQUEST
DESCRIPTOR.message_types_by_name['ListAwsIamRoleBindingsRequest'] = _LISTAWSIAMROLEBINDINGSREQUEST
DESCRIPTOR.message_types_by_name['ListAwsIamRoleBindingsResponse'] = _LISTAWSIAMROLEBINDINGSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAwsIamRoleBindingRequest'] = _DELETEAWSIAMROLEBINDINGREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AwsIamRoleBinding = _reflection.GeneratedProtocolMessageType('AwsIamRoleBinding', (_message.Message,), {
  'DESCRIPTOR' : _AWSIAMROLEBINDING,
  '__module__' : 'gateway.aws_iam_role_binding_pb2'
  # @@protoc_insertion_point(class_scope:gateway.AwsIamRoleBinding)
  })
_sym_db.RegisterMessage(AwsIamRoleBinding)

CreateAwsIamRoleBindingRequest = _reflection.GeneratedProtocolMessageType('CreateAwsIamRoleBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAWSIAMROLEBINDINGREQUEST,
  '__module__' : 'gateway.aws_iam_role_binding_pb2'
  # @@protoc_insertion_point(class_scope:gateway.CreateAwsIamRoleBindingRequest)
  })
_sym_db.RegisterMessage(CreateAwsIamRoleBindingRequest)

ListAwsIamRoleBindingsRequest = _reflection.GeneratedProtocolMessageType('ListAwsIamRoleBindingsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTAWSIAMROLEBINDINGSREQUEST,
  '__module__' : 'gateway.aws_iam_role_binding_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListAwsIamRoleBindingsRequest)
  })
_sym_db.RegisterMessage(ListAwsIamRoleBindingsRequest)

ListAwsIamRoleBindingsResponse = _reflection.GeneratedProtocolMessageType('ListAwsIamRoleBindingsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTAWSIAMROLEBINDINGSRESPONSE,
  '__module__' : 'gateway.aws_iam_role_binding_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListAwsIamRoleBindingsResponse)
  })
_sym_db.RegisterMessage(ListAwsIamRoleBindingsResponse)

DeleteAwsIamRoleBindingRequest = _reflection.GeneratedProtocolMessageType('DeleteAwsIamRoleBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAWSIAMROLEBINDINGREQUEST,
  '__module__' : 'gateway.aws_iam_role_binding_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeleteAwsIamRoleBindingRequest)
  })
_sym_db.RegisterMessage(DeleteAwsIamRoleBindingRequest)


DESCRIPTOR._options = None
_AWSIAMROLEBINDING.fields_by_name['account_id']._options = None
_AWSIAMROLEBINDING.fields_by_name['create_time']._options = None
_AWSIAMROLEBINDING.fields_by_name['principal']._options = None
_AWSIAMROLEBINDING.fields_by_name['role']._options = None
_CREATEAWSIAMROLEBINDINGREQUEST.fields_by_name['parent']._options = None
_CREATEAWSIAMROLEBINDINGREQUEST.fields_by_name['aws_iam_role_binding']._options = None
_LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['parent']._options = None
_LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['page_size']._options = None
_LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['page_token']._options = None
_LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['filter']._options = None
_LISTAWSIAMROLEBINDINGSREQUEST.fields_by_name['order_by']._options = None
_DELETEAWSIAMROLEBINDINGREQUEST.fields_by_name['aws_iam_role_binding']._options = None
# @@protoc_insertion_point(module_scope)



from . import account_pb2 as _account_pb2
from . import api_key_pb2 as _api_key_pb2
from . import audit_log_pb2 as _audit_log_pb2
from . import aws_iam_role_binding_pb2 as _aws_iam_role_binding_pb2
from . import batch_inference_job_pb2 as _batch_inference_job_pb2
from . import batch_job_pb2 as _batch_job_pb2
from . import billing_pb2 as _billing_pb2
from . import cluster_pb2 as _cluster_pb2
from . import dataset_pb2 as _dataset_pb2
from . import dataset_validation_job_pb2 as _dataset_validation_job_pb2
from . import deployed_model_pb2 as _deployed_model_pb2
from . import deployment_pb2 as _deployment_pb2
from . import deployment_template_pb2 as _deployment_template_pb2
from . import eagle_training_job_pb2 as _eagle_training_job_pb2
from . import environment_pb2 as _environment_pb2
from . import evaluation_pb2 as _evaluation_pb2
from . import evaluation_job_pb2 as _evaluation_job_pb2
from . import evaluator_pb2 as _evaluator_pb2
from . import feature_flag_pb2 as _feature_flag_pb2
from . import fine_tuning_job_pb2 as _fine_tuning_job_pb2
from . import inference_log_pb2 as _inference_log_pb2
from . import model_pb2 as _model_pb2
from . import node_pool_pb2 as _node_pool_pb2
from . import node_pool_binding_pb2 as _node_pool_binding_pb2
from . import peft_merge_job_pb2 as _peft_merge_job_pb2
from . import quota_pb2 as _quota_pb2
from . import reinforcement_fine_tuning_epoch_pb2 as _reinforcement_fine_tuning_epoch_pb2
from . import reinforcement_fine_tuning_job_pb2 as _reinforcement_fine_tuning_job_pb2
from . import reservation_pb2 as _reservation_pb2
from . import rlor_trainer_job_pb2 as _rlor_trainer_job_pb2
from . import secret_pb2 as _secret_pb2
from . import sign_in_pb2 as _sign_in_pb2
from . import snapshot_pb2 as _snapshot_pb2
from . import supervised_fine_tuning_job_pb2 as _supervised_fine_tuning_job_pb2
from . import user_pb2 as _user_pb2
from ..google.api import annotations_pb2 as _annotations_pb2
from ..google.longrunning import operations_pb2 as _operations_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



# Copyright (c) Fireworks AI, Inc. and affiliates.
#
# All Rights Reserved.

import os
from typing import List, Optional, TypeVar, Union

import grpclib
import grpc
from grpclib.client import Channel
import httpx
from functools import cache as sync_cache
from betterproto.lib.std.google.protobuf import FieldMask
from google.protobuf.field_mask_pb2 import FieldMask as SyncFieldMask
from fireworks.control_plane.generated.protos_grpcio.gateway.gateway_pb2_grpc import GatewayStub as SyncGatewayStub
from fireworks.control_plane.generated.protos_grpcio.gateway.supervised_fine_tuning_job_pb2 import (
    SupervisedFineTuningJob as SyncSupervisedFineTuningJob,
    CreateSupervisedFineTuningJobRequest as SyncCreateSupervisedFineTuningJobRequest,
)
from fireworks.control_plane.generated.protos_grpcio.gateway.dataset_pb2 import (
    Dataset as SyncDataset,
    CreateDatasetRequest as SyncCreateDatasetRequest,
    DeleteDatasetRequest as SyncDeleteDatasetRequest,
    ListDatasetsRequest as SyncListDatasetsRequest,
    GetDatasetUploadEndpointRequest as SyncGetDatasetUploadEndpointRequest,
    ValidateDatasetUploadRequest as SyncValidateDatasetUploadRequest,
)
from fireworks.control_plane.generated.protos_grpcio.gateway.supervised_fine_tuning_job_pb2 import (
    ListSupervisedFineTuningJobsRequest as SyncListSupervisedFineTuningJobsRequest,
    ListSupervisedFineTuningJobsResponse as SyncListSupervisedFineTuningJobsResponse,
)
from fireworks.control_plane.generated.protos_grpcio.gateway.deployment_pb2 import (
    ListDeploymentsRequest as SyncListDeploymentsRequest,
    UpdateDeploymentRequest as SyncUpdateDeploymentRequest,
    Deployment as SyncDeployment,
    AutoscalingPolicy as SyncAutoscalingPolicy,
    AcceleratorType as SyncAcceleratorType,
    CreateDeploymentRequest as SyncCreateDeploymentRequest,
    ScaleDeploymentRequest as SyncScaleDeploymentRequest,
    GetDeploymentRequest as SyncGetDeploymentRequest,
)
from fireworks.control_plane.generated.protos.gateway import (
    AcceleratorType,
    AutoscalingPolicy,
    CreateDatasetRequest,
    CreateDeploymentRequest,
    CreateSupervisedFineTuningJobRequest,
    Dataset,
    DeleteDatasetRequest,
    DeleteSupervisedFineTuningJobRequest,
    Deployment,
    GatewayStub,
    GetDatasetUploadEndpointRequest,
    GetDeploymentRequest,
    GetSupervisedFineTuningJobRequest,
    ListDatasetsRequest,
    ListDeploymentsRequest,
    ListModelsRequest,
    ListModelsResponse,
    ListSupervisedFineTuningJobsRequest,
    ListSupervisedFineTuningJobsResponse,
    Model,
    ScaleDeploymentRequest,
    SupervisedFineTuningJob,
    UpdateDeploymentRequest,
    CreateDatasetValidationJobRequest,
    ValidateDatasetUploadRequest,
)
from asyncstdlib.functools import cache
from openai import NOT_GIVEN, NotGiven

from grpc import AuthMetadataPlugin, AuthMetadataContext


class CustomAuthMetadata(AuthMetadataPlugin):
    def __init__(self, api_key: str):
        self._api_key = api_key

    def __call__(self, context, callback):
        metadata = [("x-api-key", self._api_key)]
        callback(metadata, None)


def _get_api_key_from_env() -> Optional[str]:
    """
    Attempts to obtain API key from the environment variable.

    Returns:
        API key retrieved from env variable or None if missing.
    """
    return os.environ.get("FIREWORKS_API_KEY")


R = TypeVar("R")


class Gateway:
    """
    Control plane gateway client that exposes its endpoints through
    convenient APIs.

    Keep the API consistent with `gateway.proto`.
    """

    def __init__(
        self,
        *,
        server_addr: str = "gateway.fireworks.ai:443",
        api_key: Optional[str] = None,
    ) -> None:
        """
        Args:
            server_addr: the network address of the gateway server.
            api_key: the API key to use for authentication.
        """
        self._server_addr = server_addr
        if not api_key:
            api_key = _get_api_key_from_env()
            if not api_key:
                raise ValueError(
                    "Fireworks API key not found. Please provide an API key either as a parameter "
                    "or by setting the FIREWORKS_API_KEY environment variable. "
                    "You can create a new API key at https://fireworks.ai/settings/users/api-keys or "
                    "by using `firectl create api-key --key-name <key-name>` command."
                )
        self._api_key = api_key
        self._host = self._server_addr.split(":")[0]
        self._port = int(self._server_addr.split(":")[1])
        self._channel = Channel(host=self._host, port=self._port, ssl=True)
        creds = grpc.composite_channel_credentials(
            grpc.ssl_channel_credentials(),
            grpc.metadata_call_credentials(CustomAuthMetadata(api_key)),
        )
        self._sync_channel = grpc.secure_channel(self._server_addr, creds)
        self._sync_stub = SyncGatewayStub(self._sync_channel)
        self._stub = GatewayStub(self._channel, metadata=[("x-api-key", api_key)])

    async def __aenter__(self):
        return self

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        self._channel.close()

    async def create_supervised_fine_tuning_job(
        self, request: CreateSupervisedFineTuningJobRequest
    ) -> SupervisedFineTuningJob:
        account_id = self.account_id()
        request.parent = f"accounts/{account_id}"
        response = await self._stub.create_supervised_fine_tuning_job(request)
        return response

    def create_supervised_fine_tuning_job_sync(
        self, request: SyncCreateSupervisedFineTuningJobRequest
    ) -> SupervisedFineTuningJob:
        account_id = self.account_id()
        request.parent = f"accounts/{account_id}"
        response = self._sync_stub.CreateSupervisedFineTuningJob(request)
        return response

    async def delete_supervised_fine_tuning_job(self, name: str) -> None:
        account_id = self.account_id()
        try:
            await self._stub.delete_supervised_fine_tuning_job(
                DeleteSupervisedFineTuningJobRequest(name=f"accounts/{account_id}/supervisedFineTuningJobs/{name}")
            )
        except grpclib.exceptions.GRPCError as e:
            if e.status == grpclib.Status.NOT_FOUND:
                return
            raise e

    async def list_supervised_fine_tuning_jobs(
        self, request: ListSupervisedFineTuningJobsRequest
    ) -> ListSupervisedFineTuningJobsResponse:
        account_id = self.account_id()
        request.parent = f"accounts/{account_id}"
        request.page_size = 200
        response = await self._stub.list_supervised_fine_tuning_jobs(request)
        return response

    def list_supervised_fine_tuning_jobs_sync(
        self, request: SyncListSupervisedFineTuningJobsRequest
    ) -> SyncListSupervisedFineTuningJobsResponse:
        account_id = self.account_id()
        request.parent = f"accounts/{account_id}"
        request.page_size = 200
        response = self._sync_stub.ListSupervisedFineTuningJobs(request)
        return response

    async def get_supervised_fine_tuning_job(self, name: str) -> Optional[SupervisedFineTuningJob]:
        account_id = self.account_id()
        try:
            response = await self._stub.get_supervised_fine_tuning_job(
                GetSupervisedFineTuningJobRequest(name=f"accounts/{account_id}/supervisedFineTuningJobs/{name}")
            )
            return response
        except grpclib.exceptions.GRPCError as e:
            if e.status == grpclib.Status.NOT_FOUND:
                return None
            raise e

    async def list_datasets(
        self,
        request: ListDatasetsRequest,
    ) -> List[Dataset]:
        account_id = self.account_id()
        request.parent = f"accounts/{account_id}"
        response = await self._stub.list_datasets(request)
        return response.datasets

    def list_datasets_sync(
        self,
        request: SyncListDatasetsRequest,
    ) -> List[SyncDataset]:
        account_id = self.account_id()
        request.parent = f"accounts/{account_id}"
        response = self._sync_stub.ListDatasets(request)
        return response.datasets

    async def delete_dataset(self, name: str) -> None:
        account_id = self.account_id()
        await self._stub.delete_dataset(DeleteDatasetRequest(name=f"accounts/{account_id}/datasets/{name}"))

    def delete_dataset_sync(self, name: str) -> None:
        account_id = self.account_id()
        self._sync_stub.DeleteDataset(SyncDeleteDatasetRequest(name=f"accounts/{account_id}/datasets/{name}"))

    async def validate_dataset(self, name: str) -> None:
        account_id = self.account_id()
        await self._stub.validate_dataset_upload(
            ValidateDatasetUploadRequest(name=f"accounts/{account_id}/datasets/{name}")
        )

    def validate_dataset_sync(self, name: str) -> None:
        account_id = self.account_id()
        self._sync_stub.ValidateDatasetUpload(
            SyncValidateDatasetUploadRequest(name=f"accounts/{account_id}/datasets/{name}")
        )

    async def create_dataset(
        self,
        request: CreateDatasetRequest,
    ) -> Dataset:
        account_id = self.account_id()
        request.parent = f"accounts/{account_id}"
        response = await self._stub.create_dataset(request)
        return response

    def create_dataset_sync(
        self,
        request: SyncCreateDatasetRequest,
    ) -> SyncDataset:
        account_id = self.account_id()
        request.parent = f"accounts/{account_id}"
        response = self._sync_stub.CreateDataset(request)
        return response

    async def get_dataset_upload_endpoint(
        self,
        name: str,
        filename_to_size: dict[str, int],
    ) -> dict[str, str]:
        account_id = self.account_id()
        name = f"accounts/{account_id}/datasets/{name}"
        response = await self._stub.get_dataset_upload_endpoint(
            GetDatasetUploadEndpointRequest(name=name, filename_to_size=filename_to_size)
        )
        return response.filename_to_signed_urls

    def get_dataset_upload_endpoint_sync(
        self,
        name: str,
        filename_to_size: dict[str, int],
    ) -> dict[str, str]:
        account_id = self.account_id()
        name = f"accounts/{account_id}/datasets/{name}"
        response = self._sync_stub.GetDatasetUploadEndpoint(
            SyncGetDatasetUploadEndpointRequest(name=name, filename_to_size=filename_to_size)
        )
        return response.filename_to_signed_urls

    async def list_models(
        self,
        *,
        parent: str = "",
        filter: str = "",
        order_by: str = "",
        include_deployed_model_refs: bool = False,
    ) -> List[Model]:
        """
        Paginates through the list of available models and returns all of them.

        Args:
            parent: resource name of the parent account,
            filter: only models satisfying the provided filter (if specified)
                will be returned. See https://google.aip.dev/160 for the filter
                grammar,
            order_by: a comma-separated list of fields to order by. e.g. "foo,bar".
                The default sort order is ascending. To specify a descending order
                for a field, append a " desc" suffix. e.g. "foo desc,bar"
                Subfields are specified with a "." character. e.g. "foo.bar".
                If not specified, the default order is by "name".

        Returns:
            list of models satisfying the retrieval criteria.
        """
        result = []
        page_token = None
        while True:
            request = ListModelsRequest(
                parent=parent,
                filter=filter,
                order_by=order_by,
                include_deployed_model_refs=include_deployed_model_refs,
                page_size=200,
            )
            if page_token is not None:
                request.page_token = page_token
            response: ListModelsResponse = await self._stub.list_models(request)
            result.extend(response.models)
            if response.total_size < len(result):
                return result
            elif response.total_size == len(result):
                return result
            page_token = response.next_page_token

    async def list_deployments(self, filter: str = ""):
        account_id = self.account_id()
        deployments = await self._stub.list_deployments(
            ListDeploymentsRequest(parent=f"accounts/{account_id}", filter=filter)
        )
        return deployments.deployments

    def list_deployments_sync(self, filter: str = "") -> List[SyncDeployment]:
        account_id = self.account_id()
        deployments = self._sync_stub.ListDeployments(
            SyncListDeploymentsRequest(parent=f"accounts/{account_id}", filter=filter)
        )
        return deployments.deployments

    async def create_deployment(
        self,
        deployment: Deployment,
    ):
        account_id = self.account_id()
        request = CreateDeploymentRequest(parent=f"accounts/{account_id}", deployment=deployment)
        created_deployment = await self._stub.create_deployment(request)
        return created_deployment

    def create_deployment_sync(
        self,
        deployment: SyncDeployment,
    ):
        account_id = self.account_id()
        request = SyncCreateDeploymentRequest(parent=f"accounts/{account_id}", deployment=deployment)
        created_deployment = self._sync_stub.CreateDeployment(request, metadata=[("x-api-key", self._api_key)])
        return created_deployment

    async def scale_deployment(self, name: str, replicas: int):
        await self._stub.scale_deployment(ScaleDeploymentRequest(name=name, replica_count=replicas))

    def scale_deployment_sync(self, name: str, replicas: int):
        self._sync_stub.ScaleDeployment(SyncScaleDeploymentRequest(name=name, replica_count=replicas))

    async def update_deployment(
        self,
        name: str,
        autoscaling_policy: Optional[AutoscalingPolicy] = None,
        accelerator_type: Optional[AcceleratorType] = None,
    ):
        deployment = Deployment(name=name)
        update_mask = FieldMask(paths=[])
        if autoscaling_policy is not None:
            deployment.autoscaling_policy = autoscaling_policy
            update_mask.paths.append("autoscaling_policy")
        if accelerator_type is not None:
            deployment.accelerator_type = accelerator_type
            update_mask.paths.append("accelerator_type")
        if len(update_mask.paths) == 0:
            return
        await self._stub.update_deployment(UpdateDeploymentRequest(deployment=deployment, update_mask=update_mask))

    def update_deployment_sync(
        self,
        deployment: SyncDeployment,
        update_mask: SyncFieldMask,
    ):
        self._sync_stub.UpdateDeployment(SyncUpdateDeploymentRequest(deployment=deployment, update_mask=update_mask))

    async def get_deployment(self, name: str) -> Deployment:
        return await self._stub.get_deployment(GetDeploymentRequest(name=name))

    def get_deployment_sync(self, name: str) -> Deployment:
        return self._sync_stub.GetDeployment(SyncGetDeploymentRequest(name=name))

    @sync_cache
    def account_id(self) -> str:
        # make curl -v -H "Authorization: Bearer XXX" https://api.fireworks.ai/verifyApiKey
        # and read x-fireworks-account-id from headers of the response
        with httpx.Client() as client:
            response = client.get(
                "https://api.fireworks.ai/verifyApiKey",
                headers={
                    "Authorization": f"Bearer {self._api_key}",
                },
            )
            return response.headers["x-fireworks-account-id"]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/prompt_tuning_job.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/prompt_tuning_job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fgateway/prompt_tuning_job.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa5\x05\n\x0fPromptTuningJob\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\x04 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\'\n\x05state\x18\x05 \x01(\x0e\x32\x11.gateway.JobStateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x06 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x19\n\nmodel_name\x18\x07 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x19\n\ndataset_id\x18\x08 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x1b\n\x0cinput_prompt\x18\t \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x1b\n\routput_prompt\x18\n \x01(\tB\x04\xe2\x41\x01\x03\x12H\n\x11prompt_to_metrics\x18\x0b \x03(\x0b\x32-.gateway.PromptTuningJob.PromptToMetricsEntry\x12\x35\n\x0bupdate_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x1a\x36\n\x14PromptToMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01:\x93\x01\xea\x41\x80\x01\n api.fireworks.ai/PromptTuningJob\x12\x39\x61\x63\x63ounts/{AccountId}/promptTuningJobs/{PromptTuningJobId}*\x10PromptTuningJobs2\x0fPromptTuningJob\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\"/\n\x19GetPromptTuningJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\"o\n\x1c\x43reatePromptTuningJobRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x39\n\x11prompt_tuning_job\x18\x02 \x01(\x0b\x32\x18.gateway.PromptTuningJobB\x04\xe2\x41\x01\x02\"\x94\x01\n\x1bListPromptTuningJobsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\"\x81\x01\n\x1cListPromptTuningJobsResponse\x12\x34\n\x12prompt_tuning_jobs\x18\x01 \x03(\x0b\x32\x18.gateway.PromptTuningJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"2\n\x1c\x44\x65letePromptTuningJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.prompt_tuning_job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_PROMPTTUNINGJOB_PROMPTTOMETRICSENTRY']._loaded_options = None
  _globals['_PROMPTTUNINGJOB_PROMPTTOMETRICSENTRY']._serialized_options = b'8\001'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['name']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['display_name']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['create_time']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['created_by']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['state']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['status']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['model_name']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['model_name']._serialized_options = b'\342A\002\002\005'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['dataset_id']._serialized_options = b'\342A\002\002\005'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['input_prompt']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['input_prompt']._serialized_options = b'\342A\002\002\005'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['output_prompt']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['output_prompt']._serialized_options = b'\342A\001\003'
  _globals['_PROMPTTUNINGJOB'].fields_by_name['update_time']._loaded_options = None
  _globals['_PROMPTTUNINGJOB'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_PROMPTTUNINGJOB']._loaded_options = None
  _globals['_PROMPTTUNINGJOB']._serialized_options = b'\352A\200\001\n api.fireworks.ai/PromptTuningJob\0229accounts/{AccountId}/promptTuningJobs/{PromptTuningJobId}*\020PromptTuningJobs2\017PromptTuningJob\202\361\004\013\n\007Account\030\001'
  _globals['_GETPROMPTTUNINGJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETPROMPTTUNINGJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CREATEPROMPTTUNINGJOBREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEPROMPTTUNINGJOBREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEPROMPTTUNINGJOBREQUEST'].fields_by_name['prompt_tuning_job']._loaded_options = None
  _globals['_CREATEPROMPTTUNINGJOBREQUEST'].fields_by_name['prompt_tuning_job']._serialized_options = b'\342A\001\002'
  _globals['_LISTPROMPTTUNINGJOBSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTPROMPTTUNINGJOBSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTPROMPTTUNINGJOBSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPROMPTTUNINGJOBSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTPROMPTTUNINGJOBSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTPROMPTTUNINGJOBSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTPROMPTTUNINGJOBSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTPROMPTTUNINGJOBSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTPROMPTTUNINGJOBSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTPROMPTTUNINGJOBSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_DELETEPROMPTTUNINGJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEPROMPTTUNINGJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_PROMPTTUNINGJOB']._serialized_start=183
  _globals['_PROMPTTUNINGJOB']._serialized_end=860
  _globals['_PROMPTTUNINGJOB_PROMPTTOMETRICSENTRY']._serialized_start=656
  _globals['_PROMPTTUNINGJOB_PROMPTTOMETRICSENTRY']._serialized_end=710
  _globals['_GETPROMPTTUNINGJOBREQUEST']._serialized_start=862
  _globals['_GETPROMPTTUNINGJOBREQUEST']._serialized_end=909
  _globals['_CREATEPROMPTTUNINGJOBREQUEST']._serialized_start=911
  _globals['_CREATEPROMPTTUNINGJOBREQUEST']._serialized_end=1022
  _globals['_LISTPROMPTTUNINGJOBSREQUEST']._serialized_start=1025
  _globals['_LISTPROMPTTUNINGJOBSREQUEST']._serialized_end=1173
  _globals['_LISTPROMPTTUNINGJOBSRESPONSE']._serialized_start=1176
  _globals['_LISTPROMPTTUNINGJOBSRESPONSE']._serialized_end=1305
  _globals['_DELETEPROMPTTUNINGJOBREQUEST']._serialized_start=1307
  _globals['_DELETEPROMPTTUNINGJOBREQUEST']._serialized_end=1357
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Code(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    OK: _ClassVar[Code]
    CANCELLED: _ClassVar[Code]
    UNKNOWN: _ClassVar[Code]
    INVALID_ARGUMENT: _ClassVar[Code]
    DEADLINE_EXCEEDED: _ClassVar[Code]
    NOT_FOUND: _ClassVar[Code]
    ALREADY_EXISTS: _ClassVar[Code]
    PERMISSION_DENIED: _ClassVar[Code]
    UNAUTHENTICATED: _ClassVar[Code]
    RESOURCE_EXHAUSTED: _ClassVar[Code]
    FAILED_PRECONDITION: _ClassVar[Code]
    ABORTED: _ClassVar[Code]
    OUT_OF_RANGE: _ClassVar[Code]
    UNIMPLEMENTED: _ClassVar[Code]
    INTERNAL: _ClassVar[Code]
    UNAVAILABLE: _ClassVar[Code]
    DATA_LOSS: _ClassVar[Code]

class JobState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    JOB_STATE_UNSPECIFIED: _ClassVar[JobState]
    JOB_STATE_CREATING: _ClassVar[JobState]
    JOB_STATE_RUNNING: _ClassVar[JobState]
    JOB_STATE_COMPLETED: _ClassVar[JobState]
    JOB_STATE_FAILED: _ClassVar[JobState]
    JOB_STATE_CANCELLED: _ClassVar[JobState]
    JOB_STATE_DELETING: _ClassVar[JobState]
    JOB_STATE_WRITING_RESULTS: _ClassVar[JobState]
    JOB_STATE_VALIDATING: _ClassVar[JobState]
    JOB_STATE_ROLLOUT: _ClassVar[JobState]
    JOB_STATE_EVALUATION: _ClassVar[JobState]
    JOB_STATE_FAILED_CLEANING_UP: _ClassVar[JobState]
    JOB_STATE_DELETING_CLEANING_UP: _ClassVar[JobState]
    JOB_STATE_POLICY_UPDATE: _ClassVar[JobState]
OK: Code
CANCELLED: Code
UNKNOWN: Code
INVALID_ARGUMENT: Code
DEADLINE_EXCEEDED: Code
NOT_FOUND: Code
ALREADY_EXISTS: Code
PERMISSION_DENIED: Code
UNAUTHENTICATED: Code
RESOURCE_EXHAUSTED: Code
FAILED_PRECONDITION: Code
ABORTED: Code
OUT_OF_RANGE: Code
UNIMPLEMENTED: Code
INTERNAL: Code
UNAVAILABLE: Code
DATA_LOSS: Code
JOB_STATE_UNSPECIFIED: JobState
JOB_STATE_CREATING: JobState
JOB_STATE_RUNNING: JobState
JOB_STATE_COMPLETED: JobState
JOB_STATE_FAILED: JobState
JOB_STATE_CANCELLED: JobState
JOB_STATE_DELETING: JobState
JOB_STATE_WRITING_RESULTS: JobState
JOB_STATE_VALIDATING: JobState
JOB_STATE_ROLLOUT: JobState
JOB_STATE_EVALUATION: JobState
JOB_STATE_FAILED_CLEANING_UP: JobState
JOB_STATE_DELETING_CLEANING_UP: JobState
JOB_STATE_POLICY_UPDATE: JobState

class Status(_message.Message):
    __slots__ = ("code", "message")
    CODE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    code: Code
    message: str
    def __init__(self, code: _Optional[_Union[Code, str]] = ..., message: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/abuse_rule.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/abuse_rule.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as gateway_dot_options__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gateway/abuse_rule.proto\x12\x07gateway\x1a\x15gateway/options.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd8\x05\n\tAbuseRule\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x37\n\x06target\x18\x02 \x01(\tB\'\xe2\x41\x02\x02\x05\xc2\xf1\x04\x1eidx_abuse_rule_target_and_type\x12N\n\x04type\x18\x03 \x01(\x0e\x32\x17.gateway.AbuseRule.TypeB\'\xe2\x41\x02\x02\x05\xc2\xf1\x04\x1eidx_abuse_rule_target_and_type\x12\x39\n\x0b\x64\x65signation\x18\x04 \x01(\x0e\x32\x1e.gateway.AbuseRule.DesignationB\x04\xe2\x41\x01\x02\x12\x36\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x35\n\x0bupdate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x0e\n\x06reason\x18\x07 \x01(\t\x12.\n\x05state\x18\x08 \x01(\x0e\x32\x18.gateway.AbuseRule.StateB\x05\xe2\x41\x02\x03\x05\"=\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06\x44OMAIN\x10\x01\x12\x06\n\x02IP\x10\x02\x12\x0b\n\x07\x41\x43\x43OUNT\x10\x03\"S\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08UPDATING\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\"T\n\x0b\x44\x65signation\x12\x1b\n\x17\x44\x45SIGNATION_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x41LLOWED\x10\x01\x12\x0b\n\x07\x42LOCKED\x10\x02\x12\x0e\n\nSUSPICIOUS\x10\x03:Y\xea\x41P\n\x1a\x61pi.fireworks.ai/AbuseRule\x12\x19\x61\x62use_rules/{AbuseRuleId}*\x0b\x61\x62use_rules2\nabuse_rule\x82\xf1\x04\x02\x18\x01\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.abuse_rule_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_ABUSERULE'].fields_by_name['name']._loaded_options = None
  _globals['_ABUSERULE'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_ABUSERULE'].fields_by_name['target']._loaded_options = None
  _globals['_ABUSERULE'].fields_by_name['target']._serialized_options = b'\342A\002\002\005\302\361\004\036idx_abuse_rule_target_and_type'
  _globals['_ABUSERULE'].fields_by_name['type']._loaded_options = None
  _globals['_ABUSERULE'].fields_by_name['type']._serialized_options = b'\342A\002\002\005\302\361\004\036idx_abuse_rule_target_and_type'
  _globals['_ABUSERULE'].fields_by_name['designation']._loaded_options = None
  _globals['_ABUSERULE'].fields_by_name['designation']._serialized_options = b'\342A\001\002'
  _globals['_ABUSERULE'].fields_by_name['create_time']._loaded_options = None
  _globals['_ABUSERULE'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_ABUSERULE'].fields_by_name['update_time']._loaded_options = None
  _globals['_ABUSERULE'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_ABUSERULE'].fields_by_name['state']._loaded_options = None
  _globals['_ABUSERULE'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_ABUSERULE']._loaded_options = None
  _globals['_ABUSERULE']._serialized_options = b'\352AP\n\032api.fireworks.ai/AbuseRule\022\031abuse_rules/{AbuseRuleId}*\013abuse_rules2\nabuse_rule\202\361\004\002\030\001'
  _globals['_ABUSERULE']._serialized_start=154
  _globals['_ABUSERULE']._serialized_end=882
  _globals['_ABUSERULE_TYPE']._serialized_start=559
  _globals['_ABUSERULE_TYPE']._serialized_end=620
  _globals['_ABUSERULE_STATE']._serialized_start=622
  _globals['_ABUSERULE_STATE']._serialized_end=705
  _globals['_ABUSERULE_DESIGNATION']._serialized_start=707
  _globals['_ABUSERULE_DESIGNATION']._serialized_end=791
# @@protoc_insertion_point(module_scope)



from ..buf.validate import validate_pb2 as _validate_pb2
from . import deployment_pb2 as _deployment_pb2
from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import visibility_pb2 as _visibility_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class WeightPrecision(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    WEIGHT_PRECISION_UNSPECIFIED: _ClassVar[WeightPrecision]
    BFLOAT16: _ClassVar[WeightPrecision]
    INT8: _ClassVar[WeightPrecision]
    NF4: _ClassVar[WeightPrecision]
WEIGHT_PRECISION_UNSPECIFIED: WeightPrecision
BFLOAT16: WeightPrecision
INT8: WeightPrecision
NF4: WeightPrecision

class EarlyStopConfig(_message.Message):
    __slots__ = ("is_set", "enabled")
    IS_SET_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    is_set: bool
    enabled: bool
    def __init__(self, is_set: bool = ..., enabled: bool = ...) -> None: ...

class BaseTrainingConfig(_message.Message):
    __slots__ = ("output_model", "base_model", "warm_start_from", "jinja_template", "learning_rate", "max_context_length", "lora_rank", "base_model_weight_precision", "accelerator_type", "accelerator_count", "region", "epochs", "batch_size")
    OUTPUT_MODEL_FIELD_NUMBER: _ClassVar[int]
    BASE_MODEL_FIELD_NUMBER: _ClassVar[int]
    WARM_START_FROM_FIELD_NUMBER: _ClassVar[int]
    JINJA_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    LEARNING_RATE_FIELD_NUMBER: _ClassVar[int]
    MAX_CONTEXT_LENGTH_FIELD_NUMBER: _ClassVar[int]
    LORA_RANK_FIELD_NUMBER: _ClassVar[int]
    BASE_MODEL_WEIGHT_PRECISION_FIELD_NUMBER: _ClassVar[int]
    ACCELERATOR_TYPE_FIELD_NUMBER: _ClassVar[int]
    ACCELERATOR_COUNT_FIELD_NUMBER: _ClassVar[int]
    REGION_FIELD_NUMBER: _ClassVar[int]
    EPOCHS_FIELD_NUMBER: _ClassVar[int]
    BATCH_SIZE_FIELD_NUMBER: _ClassVar[int]
    output_model: str
    base_model: str
    warm_start_from: str
    jinja_template: str
    learning_rate: float
    max_context_length: int
    lora_rank: int
    base_model_weight_precision: WeightPrecision
    accelerator_type: _deployment_pb2.AcceleratorType
    accelerator_count: int
    region: _deployment_pb2.Region
    epochs: int
    batch_size: int
    def __init__(self, output_model: _Optional[str] = ..., base_model: _Optional[str] = ..., warm_start_from: _Optional[str] = ..., jinja_template: _Optional[str] = ..., learning_rate: _Optional[float] = ..., max_context_length: _Optional[int] = ..., lora_rank: _Optional[int] = ..., base_model_weight_precision: _Optional[_Union[WeightPrecision, str]] = ..., accelerator_type: _Optional[_Union[_deployment_pb2.AcceleratorType, str]] = ..., accelerator_count: _Optional[int] = ..., region: _Optional[_Union[_deployment_pb2.Region, str]] = ..., epochs: _Optional[int] = ..., batch_size: _Optional[int] = ...) -> None: ...
